agenda: agenda: [ ] structure ./story_1_local treasury start --port 50000 # ^ this should create the treasury /treasury mongod --dbpath ./mongo_DB --port 27018 treasure.label { "public key": "", "private key": "", "private seed": "" } treasure.label { "public key": "", "private key": "", "private seed": "" } [ ] write hexadecimal public key to file [ ] stdin 2345 wert sdfg xcvb [ ] QR codes [ ] online [ ] Generate a QR code of a byte string for signing QR ({ unsigned: {}, }) [ ] offline [ ] take a photo of the QR code [ ] convert QR code to a hex string that is sent with { signature: hexadecimal } QR_to_UTF8 (b"") -> { unsigned: hexadecimal } [ ] sign the QR code { unsigned: hexadecimal, signed: public_key: } [ ] generate a QR code of the signature QR ({ unsigned: hexadecimal, signed: hexadecimal }) [ ] online [ ] take a photo of the { signature: hexadecimal } QR code [ ] convert the signature QR code into a { signature: hexadecimal }. [ ] online [ ] verify a signature [ ] ./story_1 create-proposal-vibes [ ] collection [ ] firefox extension: https://developer.mozilla.org/en-US/docs/Mozilla/Add-ons/WebExtensions/Your_first_WebExtension structure: [ZSH] story_1 treasury start [ZSH] story_1 lodge start /vibes steps: * build proposal certificates * build participant certificates * propose a rulership certificate { "proposal": { "stamp": } } L2: quarantine lists [ ] anyone can start a quarantine list L2 [ ] anyone can browse the quarantine lists